powered by
Returns (and prints) a summary list for ahpgaussian) objects.
ahpgaussian
# S3 method for ahpgaussian summary(object, presentation=FALSE, ...)
A given object of the class ahpgaussian
Logic. If TRUE the summary of the class ahpgaussian is showed well formated in the screen, else, return a list. The default is FALSE.
TRUE
FALSE
Potential further arguments (require by generic).
Cid Edson Povoas (cidedson@gmail.com)
dos Santos, M, Costa, I. P. de A., & Gomes, C. F. S. (2021) Multicriteria decision-making in the selection of warships: a new approach to the ahp method. International Journal of the Analytic Hierarchy Process, 13(1). <doi:10.13033/ijahp.v13i1.833>
## ## Example 1 ## ahpgaussian ## # ahpgaussian ws <- ahpgaussian(warships) summary(ws)
Run the code above in your browser using DataLab